# Python API Reference

Auto-generated from source code docstrings.

::: chess_self_coach.cli

::: chess_self_coach.config

::: chess_self_coach.analysis

::: chess_self_coach.trainer

::: chess_self_coach.server

::: chess_self_coach.importer

::: chess_self_coach.game_cache

::: chess_self_coach.opening_explorer

::: chess_self_coach.tablebase

::: chess_self_coach.cloud_eval

::: chess_self_coach.syzygy

::: chess_self_coach.updater

::: chess_self_coach.constants
